@@ -33,8 +33,8 @@
 
 #define FIELD_BUF_LEN 80
 
-struct extent_buffer *debug_corrupt_block(struct btrfs_root *root, u64 bytenr,
-				     u32 blocksize, u64 copy)
+static struct extent_buffer *debug_corrupt_block(struct btrfs_root *root,
+		u64 bytenr, u32 blocksize, u64 copy)
 {
 	int ret;
 	struct extent_buffer *eb;
@@ -475,7 +475,7 @@ static int corrupt_dir_item(struct btrfs_root *root, struct btrfs_key *key,
 	struct btrfs_trans_handle *trans;
 	struct btrfs_dir_item *di;
 	struct btrfs_path *path;
-	char *name;
+	char name[PATH_MAX];
 	struct btrfs_key location;
 	struct btrfs_disk_key disk_key;
 	unsigned long name_ptr;
@@ -514,17 +514,11 @@ static int corrupt_dir_item(struct btrfs_root *root, struct btrfs_key *key,
 	switch (corrupt_field) {
 	case BTRFS_DIR_ITEM_NAME:
 		name_len = btrfs_dir_name_len(path->nodes[0], di);
-		name = malloc(name_len);
-		if (!name) {
-			ret = -ENOMEM;
-			goto out;
-		}
 		name_ptr = (unsigned long)(di + 1);
 		read_extent_buffer(path->nodes[0], name, name_ptr, name_len);
 		name[0]++;
 		write_extent_buffer(path->nodes[0], name, name_ptr, name_len);
 		btrfs_mark_buffer_dirty(path->nodes[0]);
-		free(name);
 		goto out;
 	case BTRFS_DIR_ITEM_LOCATION_OBJECTID:
 		btrfs_dir_item_key_to_cpu(path->nodes[0], di, &location);
@@ -880,7 +874,7 @@ static int delete_csum(struct btrfs_root *root, u64 bytenr, u64 bytes)
  * If using COW, chunk recover will use the old item to recover,
  * which is still OK but we want to check the ability to rebuild chunk
  * not only restore the old ones */
-int corrupt_item_nocow(struct btrfs_trans_handle *trans,
+static int corrupt_item_nocow(struct btrfs_trans_handle *trans,
 		       struct btrfs_root *root, struct btrfs_path *path,
 		       int del)
 {
@@ -913,7 +907,7 @@ int corrupt_item_nocow(struct btrfs_trans_handle *trans,
 	}
 	return ret;
 }
-int corrupt_chunk_tree(struct btrfs_trans_handle *trans,
+static int corrupt_chunk_tree(struct btrfs_trans_handle *trans,
 		       struct btrfs_root *root)
 {
 	int ret;
@@ -986,7 +980,7 @@ free_out:
 	btrfs_free_path(path);
 	return ret;
 }
-int find_chunk_offset(struct btrfs_root *root,
+static int find_chunk_offset(struct btrfs_root *root,
 		      struct btrfs_path *path, u64 offset)
 {
 	struct btrfs_key key;
@@ -1010,7 +1004,7 @@ int find_chunk_offset(struct btrfs_root *root,
 		goto out;
 	}
 	if (ret < 0) {
-		fprintf(stderr, "Error searching chunk");
+		fprintf(stderr, "Error searching chunk\n");
 		goto out;
 	}
 out:
@@ -1217,7 +1211,7 @@ int main(int ac, char **av)
 	if (inode) {
 		struct btrfs_trans_handle *trans;
 
-		if (!strlen(field))
+		if (*field == 0)
 			print_usage(1);
 
 		trans = btrfs_start_transaction(root, 1);
@@ -1233,13 +1227,13 @@ int main(int ac, char **av)
 		goto out_close;
 	}
 	if (metadata_block) {
-		if (!strlen(field))
+		if (*field == 0)
 			print_usage(1);
 		ret = corrupt_metadata_block(root, metadata_block, field);
 		goto out_close;
 	}
 	if (corrupt_di) {
-		if (!key.objectid || !strlen(field))
+		if (!key.objectid || *field == 0)
 			print_usage(1);
 		ret = corrupt_dir_item(root, &key, field);
 		goto out_close;
@@ -1276,7 +1270,7 @@ int main(int ac, char **av)
 		goto out_close;
 	}
 	if (key.objectid || key.offset || key.type) {
-		if (!strlen(field))
+		if (*field == 0)
 			print_usage(1);
 		ret = corrupt_key(root, &key, field);
 		goto out_close;
